# territories-dashboard-lib

**Librairie Python pour créer rapidement un dashboard d'indicateurs territoriaux.**

Cette librairie permet d’analyser facilement des indicateurs sur un territoire donné, ou bien de se concentrer sur un indicateur spécifique pour une analyse détaillée.

## ✨ Fonctionnalités

-   Création rapide de dashboards interactifs
-   Vue globale par territoire ou focus par indicateur
-   Pensée pour les projets liés à l’aménagement, à la planification ou à l’analyse territoriale

## 🔧 Installation

```bash
pip install territories-dashboard-lib
```
